pyparsing.ParseResults

Module pyparsing :: Class ParseResults |
[frames] | no frames]

# Class ParseResults

source code

    object --+
             |
            ParseResults

Structured parse results, to provide multiple means of access to the parsed data:

- as a list (`len(results)`)
- by list index (`results[0], results[1]`, etc.)
- by attribute (`results.<resultsName>`)

Instance Methods
__init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=<built-in function isinstance>) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__getitem__(self, i) | source code
__setitem__(self, k, v, isinstance=<built-in function isinstance>) | source code
__delitem__(self, i) | source code
__contains__(self, k) | source code
__len__(self) | source code
__bool__(self) | source code
__nonzero__(self) | source code
__iter__(self) | source code
__reversed__(self) | source code
iterkeys(self) Returns an iterator of all named result keys (Python 2.x only). | source code
itervalues(self) Returns an iterator of all named result values (Python 2.x only). | source code
iteritems(self) Returns an iterator of all named result key-value tuples (Python 2.x only). | source code
keys(self) Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x). | source code
values(self) Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x). | source code
items(self) Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x). | source code
haskeys(self) Since keys() returns an iterator, this method is helpful in bypassing code that looks for the existence of any defined results names. | source code
pop(self, *args, **kwargs) Removes and returns item at specified index (default=last). | source code
get(self, key, defaultValue=None) Returns named result matching the given key, or if there is no such name, then returns the given `defaultValue` or `None` if no `defaultValue` is specified. | source code
insert(self, index, insStr) Inserts new element at location index in the list of parsed tokens. | source code
append(self, item) Add single element to end of ParseResults list of elements. | source code
extend(self, itemseq) Add sequence of elements to end of ParseResults list of elements. | source code
clear(self) Clear all elements and results names. | source code
__getattr__(self, name) | source code
__add__(self, other) | source code
__iadd__(self, other) | source code
__radd__(self, other) | source code
__repr__(self) repr(x) | source code
__str__(self) str(x) | source code
asList(self) Returns the parse results as a nested list of matching tokens, all converted to strings. | source code
asDict(self) Returns the named parse results as a nested dictionary. | source code
copy(self) Returns a new copy of a `ParseResults` object. | source code
asXML(self, doctag=None, namedItemsOnly=False, indent=`'````'`, formatted=True) Returns the parse results as XML. | source code
getName(self) Returns the results name for this token expression. | source code
dump(self, indent=`'````'`, depth=0) Diagnostic method for listing out the contents of a `ParseResults`. | source code
pprint(self, *args, **kwargs) Pretty-printer for parsed results as a list, using the `pprint` module. | source code
__getstate__(self) | source code
__setstate__(self, state) | source code
__getnewargs__(self) | source code
__dir__(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, toklist=None, name=None, asList=True, modal=True) | source code

Properties
Inherited from `object`: `__class__`

Method Details

### __new__(cls, toklist=None, name=None, asList=True, modal=True) Static Method | source code
Returns: a new object with type S, a subtype of T Overrides: object.__new__ (inherited documentation)

### __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=<built-in function isinstance>) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### pop(self, *args, **kwargs) | source code
Removes and returns item at specified index (default=last). Supports both list and dict semantics for pop(). If passed no argument or an integer argument, it will use list semantics and pop tokens from the list of parsed tokens. If passed a non-integer argument (most likely a string), it will use dict semantics and pop the corresponding value from any defined results names. A second default return value argument is supported, just as in dict.pop().

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### asXML(self, doctag=None, namedItemsOnly=False, indent=`'````'`, formatted=True) | source code
Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.

### dump(self, indent=`'````'`, depth=0) | source code
Diagnostic method for listing out the contents of a `ParseResults`. Accepts an optional `indent` argument so that this string can be embedded in a nested display of other data.

### pprint(self, *args, **kwargs) | source code
Pretty-printer for parsed results as a list, using the `pprint` module. Accepts additional positional or keyword args as defined for the `pprint.pprint` method. (http://docs.python.org/3/library/pprint.html#pprint.pprint)